@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-11-29'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -190,11 +190,27 @@ sub complete_array_elem {
             $re .= '(?:\W+\w+)*\W+' if $i;
             $re .= quotemeta($split_wordn[$i]).'\w*';
         }
-        #say "D:re=$re";
+        #say "D:entering word mode, re=$re";
         $re = qr/$re/;
 
         for my $i (0..$#{$array}) {
-            next unless $arrayn[$i] =~ $re;
+            my $match;
+            {
+                if ($arrayn[$i] =~ $re) {
+                    $match++;
+                    last;
+                }
+                # try splitting CamelCase into Camel-Case
+                my $tmp = $array->[$i];
+                if ($tmp =~ s/([a-z0-9_])([A-Z])/$1-$2/g) {
+                    $tmp = uc($tmp) if $ci; $tmp =~ s/_/-/g if $map_case; # normalize again
+                    if ($tmp =~ $re) {
+                        $match++;
+                        last;
+                    }
+                }
+            }
+            next unless $match;
             push @words, $array->[$i];
         }
     }
@@ -396,7 +412,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.41 of Complete::Util (from Perl distribution Complete-Util), released on 2015-11-29.
+This document describes version 0.42 of Complete::Util (from Perl distribution Complete-Util), released on 2015-12-17.
 
 =head1 DESCRIPTION
 
@@ -545,7 +561,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
 
 =head1 BUGS
 
